import requests

from client.session import ClientSession
from client.error import SessionNotCreatedException, IncorrectUsernameOrPasswordException, SppNotRunningException, TotpEnrollmentIncompleteException, TotpTokenIncorrectException


class Client:

	def create_session(self, username, password, token=None):

		try:
			url = 'http://localhost:8082/api/endeavour/session?screenInfo=1'
			headers = {
				'Accept': 'application/json',
				'Content-Type': 'application/json'
			}

			body = None

			if token is not None:
				body = {
					'totp': {
						'token': token
					}
				}

			response = requests.post(url, headers=headers, auth=(username, password), json=body)
			status_code = response.status_code
			json = response.json()

			if status_code == 200:

				if 'sessionid' in json:
					return ClientSession(json['sessionid'])
				
				else:
					raise SessionNotCreatedException('Failed to created SPP session.')
			
			elif response.status_code == 401:

				if has_exception(json, 'XSBAuthenticationException'):
					raise IncorrectUsernameOrPasswordException('Incorrect SPP username or password')

				elif has_exception(json, 'TotpEnrollmentIncompleteException'):
					raise TotpEnrollmentIncompleteException('TOTP enrollment is incomplete for this user. Complete TOTP enrollment for this user before continuing.')

				elif has_exception(json, 'TotpTokenIncorrectException'):
					raise TotpTokenIncorrectException('Missing or incorrect TOTP token for user. Ensure that the correct TOTP token is included (using --token) when authenticating with this user.')

		except ConnectionError:
			raise SppNotRunningException('SPP API is not reachable. Ensure SPP is running and reachable.')

def has_exception(json, error):
	return 'id' in json and json['id'] == error