import requests


class ClientSession:

	def __init__(self, session_id):
		self._session_id = session_id

	def get(self, url, headers={}, body=None):

		sessioned_headers = self._sessioned_headers(headers)

		return requests.get(url, headers=sessioned_headers, data=body)

	def _sessioned_headers(self, headers):

		sessioned_headers = headers.copy()
		sessioned_headers['x-endeavour-sessionid'] = self._session_id

		return sessioned_headers

	def post(self, url, headers={}, body=None):
		
		sessioned_headers = self._sessioned_headers(headers)

		return requests.post(url, headers=sessioned_headers, data=body)

	def put(self, url, headers={}, body=None):
		
		sessioned_headers = self._sessioned_headers(headers)

		return requests.put(url, headers=sessioned_headers, data=body)

	def delete(self, url, headers={}, body=None):

		sessioned_headers = self._sessioned_headers(headers)

		return requests.delete(url, headers=sessioned_headers, data=body)