import click

from tabulate import tabulate

from cli.format import title, subtitle, indent
from config.system import ConfigurationManager
from config.update import Updater


@click.group()
def config():
    pass

@config.group()
def current():
    pass

@config.group()
def updates():
    pass

@current.command('show', help='Shows the current configuration')
@click.pass_context
def show_config(ctx):

    config_manager = ConfigurationManager(ctx.obj['config_path'])
    config = config_manager.load()

    click.echo('')
    title('Configuration')
    click.echo('')
    click.echo(indent(config.to_json()))
    click.echo('')


@updates.command('show', help='Shows all of the configuration update steps')
@click.pass_context
def show_config_updates(ctx):

    config_manager = ConfigurationManager(ctx.obj['config_path'])
    config = config_manager.load()

    updater = Updater(config, config_manager)

    headers = ['Operation', 'Description']
    rows = [(step.operation, step.description) for step in updater.steps]

    click.echo('')
    title('Configuration Updates')
    click.echo('')
    click.echo(indent(tabulate(rows, headers=headers)))
    click.echo('')


@updates.command('run', help='Runs all of the configuration update steps')
@click.pass_context
def run_config_updates(ctx):

    config_path = ctx.obj['config_path']

    config_manager = ConfigurationManager(config_path)
    config = config_manager.load()

    updater = Updater(config, config_manager)

    click.echo('')
    title('Configuration Updates Executed')
    click.echo('')
    subtitle('Configuration')
    click.echo(indent('Path:    {}'.format(config_path)))
    click.echo('')

    updater.update()
    config = config_manager.load()

    headers = ['Operation', 'Description']
    rows = [(step.operation, step.description) for step in updater.steps]

    subtitle('Steps Executed')
    click.echo('')
    click.echo(indent(tabulate(rows, headers=headers), space=4))
    click.echo('')
    subtitle('Resulting Configuration')
    click.echo('')
    click.echo(indent(config.to_json(), space=4))
    click.echo('')
